package com.aucma.production.service;

import java.util.List;
import com.aucma.production.domain.CalendarInfo;

/**
 * 生产日历Service接口
 * 
 * @author Yinq
 * @date 2023-11-23
 */
public interface ICalendarInfoService 
{
    /**
     * 查询生产日历
     * 
     * @param objId 生产日历主键
     * @return 生产日历
     */
    public CalendarInfo selectCalendarInfoByObjId(Long objId);

    /**
     * 查询生产日历列表
     * 
     * @param calendarInfo 生产日历
     * @return 生产日历集合
     */
    public List<CalendarInfo> selectCalendarInfoList(CalendarInfo calendarInfo);

    /**
     * 新增生产日历
     * 
     * @param calendarInfo 生产日历
     * @return 结果
     */
    public int insertCalendarInfo(CalendarInfo calendarInfo);

    /**
     * 修改生产日历
     * 
     * @param calendarInfo 生产日历
     * @return 结果
     */
    public int updateCalendarInfo(CalendarInfo calendarInfo);

    /**
     * 批量删除生产日历
     * 
     * @param objIds 需要删除的生产日历主键集合
     * @return 结果
     */
    public int deleteCalendarInfoByObjIds(Long[] objIds);

    /**
     * 删除生产日历信息
     * 
     * @param objId 生产日历主键
     * @return 结果
     */
    public int deleteCalendarInfoByObjId(Long objId);


}
