package com.aucma.production.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.aucma.common.utils.DateUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.aucma.common.annotation.Log;
import com.aucma.common.core.controller.BaseController;
import com.aucma.common.core.domain.AjaxResult;
import com.aucma.common.enums.BusinessType;
import com.aucma.production.domain.CalendarInfo;
import com.aucma.production.service.ICalendarInfoService;
import com.aucma.common.utils.poi.ExcelUtil;
import com.aucma.common.core.page.TableDataInfo;

/**
 * 生产日历Controller
 *
 * @author Yinq
 * @date 2023-11-23
 */
@RestController
@RequestMapping("/production/calendarInfo" )
public class CalendarInfoController extends BaseController {
    @Autowired
    private ICalendarInfoService calendarInfoService;

    /**
     * 查询生产日历列表
     */
    @PreAuthorize("@ss.hasPermi('production:calendarInfo:list')" )
    @GetMapping("/list" )
    public TableDataInfo list(CalendarInfo calendarInfo) {
        startPage();
        List<CalendarInfo> list = calendarInfoService.selectCalendarInfoList(calendarInfo);
        return getDataTable(list);
    }

    /**
     * 导出生产日历列表
     */
    @PreAuthorize("@ss.hasPermi('production:calendarInfo:export')" )
    @Log(title = "生产日历" , businessType = BusinessType.EXPORT)
    @PostMapping("/export" )
    public void export(HttpServletResponse response, CalendarInfo calendarInfo) {
        List<CalendarInfo> list = calendarInfoService.selectCalendarInfoList(calendarInfo);
        ExcelUtil<CalendarInfo> util = new ExcelUtil<CalendarInfo>(CalendarInfo. class);
        util.exportExcel(response, list, "生产日历数据" );
    }

    /**
     * 获取生产日历详细信息
     */
    @PreAuthorize("@ss.hasPermi('production:calendarInfo:query')" )
    @GetMapping(value = "/{objId}" )
    public AjaxResult getInfo(@PathVariable("objId" ) Long objId) {
        return success(calendarInfoService.selectCalendarInfoByObjId(objId));
    }

    /**
     * 新增生产日历
     */
    @PreAuthorize("@ss.hasPermi('production:calendarInfo:add')" )
    @Log(title = "生产日历" , businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CalendarInfo calendarInfo) {
        calendarInfo.setCreatedBy(getUsername());
        calendarInfo.setCreatedTime(DateUtils.getNowDate());
        return toAjax(calendarInfoService.insertCalendarInfo(calendarInfo));
    }

    /**
     * 修改生产日历
     */
    @PreAuthorize("@ss.hasPermi('production:calendarInfo:edit')" )
    @Log(title = "生产日历" , businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CalendarInfo calendarInfo) {
        calendarInfo.setUpdatedBy(getUsername());
        calendarInfo.setUpdatedTime(DateUtils.getNowDate());
        return toAjax(calendarInfoService.updateCalendarInfo(calendarInfo));
    }

    /**
     * 删除生产日历
     */
    @PreAuthorize("@ss.hasPermi('production:calendarInfo:remove')" )
    @Log(title = "生产日历" , businessType = BusinessType.DELETE)
    @DeleteMapping("/{objIds}" )
    public AjaxResult remove(@PathVariable Long[] objIds) {
        return toAjax(calendarInfoService.deleteCalendarInfoByObjIds(objIds));
    }


}
